aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--justfile2
-rw-r--r--main.go4
2 files changed, 3 insertions, 3 deletions
diff --git a/justfile b/justfile
index 16bb53e..7cfa3aa 100644
--- a/justfile
+++ b/justfile
@@ -1,4 +1,4 @@
-# fluxrec task automation (planned commands per PLAN.md, only implemented ones run)
+# fluxrec task automation
build:
go build -o fluxrec .
diff --git a/main.go b/main.go
index b5249e4..d5adc15 100644
--- a/main.go
+++ b/main.go
@@ -1,5 +1,5 @@
// fluxrec command-line tool.
// Personal Miniflux article recommender; see PLAN.md for the design.
package main
import (
@@ -61,7 +61,7 @@ func main() {
func printHelp() {
fmt.Printf(`fluxrec <command> [arguments]
-Personal Miniflux article recommender (see PLAN.md).
+Personal Miniflux article recommender (see README.md).
Commands:
score Score stdin titles with a trained model (debugging)
@@ -1,5 +1,5 @@
// fluxrec command-line tool.
-// Personal Miniflux article recommender; see PLAN.md for the design.
+// Personal Miniflux article recommender; see README.md.
package main
import (